==> java-sdk-4.15.7-sources.jar: com/baidu/aip/bodyanalysis/BodyAnalysisConsts.java <==
/*
 * Copyright 2017 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidu.aip.bodyanalysis;

public class BodyAnalysisConsts {

    static final String BODY_ANALYSIS = "https://aip.baidubce.com/rest/2.0/image-classify/v1/body_analysis";

    static final String BODY_ATTR = "https://aip.baidubce.com/rest/2.0/image-classify/v1/body_attr";

    static final String BODY_NUM = "https://aip.baidubce.com/rest/2.0/image-classify/v1/body_num";

    static final String GESTURE = "https://aip.baidubce.com/rest/2.0/image-classify/v1/gesture";

    static final String BODY_SEG = "https://aip.baidubce.com/rest/2.0/image-classify/v1/body_seg";

    static final String DRIVER_BEHAVIOR = "https://aip.baidubce.com/rest/2.0/image-classify/v1/driver_behavior";

    static final String BODY_TRACKING = "https://aip.baidubce.com/rest/2.0/image-classify/v1/body_tracking";

    static final String HAND_ANALYSIS = "https://aip.baidubce.com/rest/2.0/image-classify/v1/hand_analysis";

}

==> java-sdk-4.16.16-sources.jar: com/baidu/aip/bodyanalysis/BodyAnalysisConsts.java <==
/*
 * Copyright 2017 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidu.aip.bodyanalysis;

public class BodyAnalysisConsts {

    static final String BODY_ANALYSIS = "https://aip.baidubce.com/rest/2.0/image-classify/v1/body_analysis";

    static final String BODY_ATTR = "https://aip.baidubce.com/rest/2.0/image-classify/v1/body_attr";

    static final String BODY_NUM = "https://aip.baidubce.com/rest/2.0/image-classify/v1/body_num";

    static final String GESTURE = "https://aip.baidubce.com/rest/2.0/image-classify/v1/gesture";

    static final String BODY_SEG = "https://aip.baidubce.com/rest/2.0/image-classify/v1/body_seg";

    static final String DRIVER_BEHAVIOR = "https://aip.baidubce.com/rest/2.0/image-classify/v1/driver_behavior";

    static final String BODY_TRACKING = "https://aip.baidubce.com/rest/2.0/image-classify/v1/body_tracking";

    static final String HAND_ANALYSIS = "https://aip.baidubce.com/rest/2.0/image-classify/v1/hand_analysis";

    static final String BODY_DANGER_V1 = "https://aip.baidubce.com/rest/2.0/video-classify/v1/body_danger";
    static final String FINGERTIP_V1 = "https://aip.baidubce.com/rest/2.0/image-classify/v1/fingertip";

}
